dottorrent
==========

High-level Python 3 library and CLI tool for creating .torrent files

Documentation
-------------

Full documentation on how to use the dottorrent as a Python library and
from the command line is available at `dottorrent.readthedocs.io <http://dottorrent.readthedocs.io>`_.

.. image:: https://readthedocs.org/projects/dottorrent/badge/


Installation
------------

Stable releases are available on PyPI and can be installed using ``pip``.
::

	pip install dottorrent

License
-------

`MIT <https://opensource.org/licenses/MIT>`_